[GnomeMeeting-devel-list] [PATCH] "history" -> "calls history"



Hi,

very small patch, that only changes a little a few comments.

Snark
diff -ur gnomemeeting-cvs-20040125.CVS/src/ldap_window.h gnomemeeting-cvs-20040125.CVS.patched/src/ldap_window.h
--- gnomemeeting-cvs-20040125.CVS/src/ldap_window.h	2004-01-20 12:46:57.000000000 +0100
+++ gnomemeeting-cvs-20040125.CVS.patched/src/ldap_window.h	2004-01-25 17:42:21.000000000 +0100
@@ -181,7 +181,7 @@
  *                 a row corresonding to an user.
  * BEHAVIOR     :  Add the user name in the combo box and call him or transfer
  *                 the call to that user.
- * PRE          :  data is the page type or 3 if contact activated from history
+ * PRE          :  data is the page type or 3 if contact activated from calls history
  */
 void contact_activated_cb (GtkTreeView *,
 			   GtkTreePath *,
diff -ur gnomemeeting-cvs-20040125.CVS/src/tools.h gnomemeeting-cvs-20040125.CVS.patched/src/tools.h
--- gnomemeeting-cvs-20040125.CVS/src/tools.h	2004-01-24 23:27:40.000000000 +0100
+++ gnomemeeting-cvs-20040125.CVS.patched/src/tools.h	2004-01-25 17:40:47.000000000 +0100
@@ -59,14 +59,14 @@
 
 
 /* DESCRIPTION  :  /
- * BEHAVIOR     :  Populate the history window.
+ * BEHAVIOR     :  Populate the calls history window.
  * PRE          :  /
  */
 void gnomemeeting_calls_history_window_populate ();
 
 
 /* DESCRIPTION  :  /
- * BEHAVIOR     :  Add a call to the history window.
+ * BEHAVIOR     :  Add a call to the calls history window.
  * PRE          :  /
  */
 void gnomemeeting_calls_history_window_add_call (int,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff -ur gnomemeeting-cvs-20040125.CVS/src/ldap_window.cpp gnomemeeting-cvs-20040125.CVS.patched/src/ldap_window.cpp
--- gnomemeeting-cvs-20040125.CVS/src/ldap_window.cpp	2004-01-21 14:02:25.000000000 +0100
+++ gnomemeeting-cvs-20040125.CVS.patched/src/ldap_window.cpp	2004-01-25 17:43:12.000000000 +0100
@@ -1222,7 +1222,7 @@
 	    }
 	  }
 	}
-	else /* No props and delete if the contact is in the history */
+	else /* No props and delete if the contact is in the calls history */
 	  server_contact_menu [1] = endt;	
 
 	gtk_build_menu (menu, server_contact_menu, NULL, NULL);
@@ -1781,7 +1781,7 @@
  *                 a row corresonding to an user.
  * BEHAVIOR     :  Add the user name in the combo box and call him or transfer
  *                 the call to that user.
  * PRE          :  data is the page type or 3 if contact activated from history
  */
 void 
 contact_activated_cb (GtkTreeView *tree_view,
@@ -1818,7 +1818,7 @@
     if (contact_url) {	  
     
       /* if we are waiting for a call, add the IP
-	 to the history, and call that user       */
+	 to the calls history, and call that user       */
       if (GnomeMeeting::Process ()->Endpoint ()->GetCallingState () == GMH323EndPoint::Standby) {
       
 	/* this function will store a copy of text */
@@ -1781,7 +1781,7 @@
  * BEHAVIOR     :  Add the user name in the combo box and call him or transfer
  *                 the call to that user.
- * PRE          :  data is the page type or 3 if contact activated from history
+ * PRE          :  data is the page type or 3 if contact activated from calls history
  */
 void 